@@ -5,21 +5,33 @@ package Task::BeLike::Shantanu;
 
 # PODNAME: Task::BeLike::Shantanu
 # ABSTRACT: All my default Modules in a perl installation
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 # Dependencies
+
+use 5.010;
 use Acme::CPANAuthors::India;
 use Dist::Zilla::PluginBundle::SHANTANU;
 use File::UStore;
 use Pod::Weaver::PluginBundle::SHANTANU;
-use Printer::Thermal;
 
 use autodie;
 use App::cpanminus;
 use App::cpanoutdated;
+use Authen::Passphrase;
 use Catalyst 5.90000;
+use Catalyst::Plugin::Assets;
+use Catalyst::Plugin::Authentication;
+use Catalyst::Plugin::Session;
+use Catalyst::Plugin::Session::Store::FastMmap;
+use Catalyst::Plugin::StatusMessage;
+use Catalyst::Runtime;
 use Data::Dumper 2.14;
+use DateTime::Format::MySQL;
 use Device::SerialPort;
 use DBIx::Class;
+use DBIx::Class::PassphraseColumn;
+use DBIx::Class::Validation;
+use DBIx::Class::InflateColumn::Authen::Passphrase;
 use Digest::MD5;
 use Dist::Zilla 4.300000;
 use ExtUtils::MakeMaker 6.60;
@@ -29,6 +41,7 @@ use File::Copy 2.20;
 use File::Find::Rule 0.33;
 use File::HomeDir 1.00;
 use File::Spec 3.40;
+use HTML::FormFu::Constraint::DBIC::Unique;
 use IO::Handle;
 use IO::Socket;
 use JSON::XS;
@@ -55,7 +68,7 @@ Task::BeLike::Shantanu - All my default Modules in a perl installation
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
@@ -80,6 +93,10 @@ L<https://github.com/shantanubhadoria/task-belike-shantanu>
 
 Shantanu Bhadoria <shantanu@cpan.org>
 
+=head1 CONTRIBUTOR
+
+Shantanu <shantanu@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2013 by Shantanu Bhadoria.
